[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- ete2.phylo.evolevents.EvolEvent: Basic evolutionary event.
- ete2.treeview.drawer.TreeImageProperties
- object: The most base type
  - ete2.coretype.arraytable.ArrayTable: This object is thought to work with matrix datasets (like microarrays).
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - ete2.parser.newick.NewickError: Exception class designed for NewickIO errors.
      - ete2.coretype.tree.TreeError: Exception class designed for tree.
  - ete2.treeview.faces.Face: Standard definition of a face node object.
    - ete2.treeview.faces.ImgFace: Creates a new image face object.
    - ete2.treeview.faces.ProfileFace: Creates a new vector profile face object.
    - ete2.treeview.faces.SequenceFace: Creates a new molecular sequence face object.
    - ete2.treeview.faces.TextFace: Creates a new text face object.
      - ete2.treeview.faces.AttrFace: Creates a new text attribute face object.
    - ete2.treeview.faces.ValidationFace: Creates a new clustering validation face
  - ete2.phylomedb.phylomeDB.PhylomeDBConnector: Reuturns a connector to a phylomeDB database.
  - ete2.coretype.seqgroup.SeqGroup: SeqGroup class can be used to store a set of sequences (aligned or not).
  - ete2.coretype.tree.TreeNode: TreeNode (Tree) class is used to store a tree structure.
    - ete2.clustering.clustertree.ClusterNode: Creates a new Cluster Tree object, which is a collection of ClusterNode instances connected in a hierarchical way, and representing a clustering result.
    - ete2.phylo.phylotree.PhyloNode: Re-implementation of the standart TreeNode instance.
  - ete2.treeview._about.Ui_About
  - ete2.treeview._search_dialog.Ui_Dialog
  - ete2.treeview._mainwindow.Ui_MainWindow
  - ete2.treeview._show_newick.Ui_Newick
  - ete2.treeview._open_newick.Ui_OpenNewick
  - int: int(x[, base]) -> integer
    - PyQt4.QtGui.QGraphicsItem.CacheMode
    - PyQt4.QtGui.QGraphicsView.CacheModeFlag
    - PyQt4.QtGui.QDialog.DialogCode
    - PyQt4.QtGui.QMainWindow.DockOption
    - PyQt4.QtGui.QGraphicsView.DragMode
    - PyQt4.QtGui.QAbstractItemDelegate.EndEditHint
    - PyQt4.QtGui.QGraphicsItem.GraphicsItemChange
    - PyQt4.QtGui.QGraphicsItem.GraphicsItemFlag
    - PyQt4.QtGui.QGraphicsScene.ItemIndexMethod
    - PyQt4.QtGui.QGraphicsView.OptimizationFlag
    - PyQt4.QtGui.QPaintDevice.PaintDeviceMetric
    - PyQt4.QtGui.QWidget.RenderFlag
    - PyQt4.QtGui.QGraphicsScene.SceneLayer
    - PyQt4.QtGui.QFrame.Shadow
    - PyQt4.QtGui.QFrame.Shape
    - PyQt4.QtGui.QGraphicsPixmapItem.ShapeMode
    - PyQt4.QtGui.QFrame.StyleMask
    - PyQt4.QtGui.QGraphicsView.ViewportAnchor
    - PyQt4.QtGui.QGraphicsView.ViewportUpdateMode
  - sip.simplewrapper
    - PyQt4.QtGui.QGraphicsView.CacheMode
    - PyQt4.QtGui.QMainWindow.DockOptions
    - PyQt4.QtGui.QGraphicsItem.GraphicsItemFlags
    - PyQt4.QtGui.QGraphicsView.OptimizationFlags
    - PyQt4.QtGui.QPaintDevice
      - PyQt4.QtGui.QWidget
        - PyQt4.QtGui.QDialog
          - ete2.treeview.drawer.NewickDialog
        - PyQt4.QtGui.QFrame
          - PyQt4.QtGui.QAbstractScrollArea
            - PyQt4.QtGui.QGraphicsView
              - ete2.treeview.drawer._MainView
        - PyQt4.QtGui.QMainWindow
          - ete2.treeview.drawer._MainApp
        - ete2.treeview.drawer._PropModeChooser
        - ete2.treeview.drawer._PropertiesDialog
    - PyQt4.QtGui.QWidget.RenderFlags
    - PyQt4.QtGui.QGraphicsScene.SceneLayers
    - sip.wrapper
      - PyQt4.QtGui.QGraphicsItem
        - PyQt4.QtGui.QAbstractGraphicsShapeItem
          - PyQt4.QtGui.QGraphicsRectItem
            - ete2.treeview.drawer._HighlighterItem
            - ete2.treeview.drawer._NodeItem
            - ete2.treeview.drawer._SelectorItem
          - PyQt4.QtGui.QGraphicsSimpleTextItem
            - ete2.treeview.drawer._TextItem: Manage faces on Scene
        - PyQt4.QtGui.QGraphicsPixmapItem
          - ete2.treeview.drawer._FaceItem: Manage faces on Scene
      - PyQt4.QtCore.QObject
        - PyQt4.QtGui.QAbstractItemDelegate
          - PyQt4.QtGui.QItemDelegate
            - ete2.treeview.drawer._TableItem
        - PyQt4.QtGui.QGraphicsScene
          - ete2.treeview.drawer._TreeScene
        - PyQt4.QtGui.QWidget
          - PyQt4.QtGui.QDialog
            - ete2.treeview.drawer.NewickDialog
          - PyQt4.QtGui.QFrame
            - PyQt4.QtGui.QAbstractScrollArea
              - PyQt4.QtGui.QGraphicsView
                - ete2.treeview.drawer._MainView
          - PyQt4.QtGui.QMainWindow
            - ete2.treeview.drawer._MainApp
          - ete2.treeview.drawer._PropModeChooser
          - ete2.treeview.drawer._PropertiesDialog